@@ -1,23 +1,38 @@
-#' Format relationship description
+#' Format and print relationship descriptions
 #'
-#' This is the main formatting function called by `print.pairrel()`.
+#' This documents the options for formatting and printing the output of
+#' [verbalise()].
 #'
 #' @param x An output of [verbalise()].
+#' @param ... Arguments passed on to `format.pairrel()`.
 #' @param cap A logical indicating if the first letter of each path description
 #'   should be capitalised. By default TRUE.
+#' @param simplify A logical. If TRUE, the descriptions of lineal and avuncular
+#'   relationships are simplified. Default: FALSE.
 #' @param includePaths A logical indicating if the complete paths should be
 #'   included in the output. By default TRUE.
-#' @param ... Not used.
 #'
 #' @export
-format.pairrel = function(x, cap = TRUE, includePaths = TRUE, ...) {
+print.pairrel = function(x, ...) {
+  txt = format(x, ...)
+  cat(txt, sep = "\n")
+  invisible(x)
+}
+
+#' @rdname print.pairrel
+#' @export
+format.pairrel = function(x, cap = TRUE, simplify = FALSE,
+                          includePaths = !simplify, ...) {
 
   if(length(x) == 1 && x[[1]]$type == "unrelated")
-    return("Unrelated")
+    return(if(cap) "Unrelated" else "unrelated")
 
   # Descriptions: Relationship + details
-  descrips = vapply(x, FUN.VALUE = "", function(p)
-    if(is.null(p$details)) p$rel else paste0(p$rel, ": ", p$details))
+  descrips = vapply(x, FUN.VALUE = "", function(p) {
+    if(simplify && !is.null(p$details2)) p$details2
+    else if(is.null(p$details)) p$rel
+    else paste0(p$rel, ": ", p$details)
+  })
 
   # Collect path groups
   uniq = unique.default(descrips)
@@ -36,11 +51,3 @@ format.pairrel = function(x, cap = TRUE, includePaths = TRUE, ...) {
 
   s
 }
-
-
-#' @export
-print.pairrel = function(x, ...) {
-  txt = format(x, ...)
-  cat(txt, sep = "\n")
-  invisible(x)
-}
